<?php $TRANSLATIONS = array(
"Unable to load list from App Store" => "Klarer ikkje å laste inn liste fra App Store",
"Authentication error" => "Feil i autentisering",
"Email saved" => "E-postadresse lagra",
"Invalid email" => "Ugyldig e-postadresse",
"OpenID Changed" => "OpenID endra",
"Invalid request" => "Ugyldig førespurnad",
"Language changed" => "Språk endra",
"Disable" => "Slå av",
"Enable" => "Slå på",
"__language_name__" => "Nynorsk",
"Select an App" => "Vel ein applikasjon",
"Ask a question" => "Spør om noko",
"Problems connecting to help database." => "Problem ved tilkopling til hjelpedatabasen.",
"Go there manually." => "Gå der på eigen hand.",
"Answer" => "Svar",
"Unable to change your password" => "Klarte ikkje å endra passordet",
"Current password" => "Passord",
"New password" => "Nytt passord",
"show" => "vis",
"Change password" => "Endra passord",
"Email" => "Epost",
"Your email address" => "Din epost addresse",
"Fill in an email address to enable password recovery" => "Fyll inn din e-post addresse for og kunne motta passord tilbakestilling",
"Language" => "Språk",
"Help translate" => "Hjelp oss å oversett",
"use this address to connect to your ownCloud in your file manager" => "bruk denne adressa for å kopla til ownCloud i filhandsamaren din",
"Name" => "Namn",
"Password" => "Passord",
"Groups" => "Grupper",
"Create" => "Lag",
"Quota" => "Kvote",
"Delete" => "Slett"
);
